/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.shiro.web.jaxrs;

import javax.ws.rs.container.ContainerRequestContext;
import javax.ws.rs.container.ContainerRequestFilter;
import javax.ws.rs.container.PreMatching;
import javax.ws.rs.ext.Provider;
import java.io.IOException;

/**
 * A {@link ContainerRequestFilter} that replaces the {@link javax.ws.rs.core.SecurityContext}
 * with a {@link ShiroSecurityContext}.
 * @since 1.4
 */
@Provider
@PreMatching
public class SubjectPrincipalRequestFilter implements ContainerRequestFilter {
    public static final String SHIRO_WEB_JAXRS_DISABLE_PRINCIPAL_PARAM = "org.apache.shiro.web.jaxrs.disable-principal";

    @Override
    public void filter(ContainerRequestContext requestContext) throws IOException {
        if (!Boolean.TRUE.equals(requestContext.getProperty(SHIRO_WEB_JAXRS_DISABLE_PRINCIPAL_PARAM))) {
            requestContext.setSecurityContext(new ShiroSecurityContext(requestContext));
        }
    }
}
